`gradio <https://www.gradio.app/>`__ interfaces for Deep Learning Docker images that
use Redis for receiving data to make predictions on.

`https://www.data-mining.co.nz/docker-images/ <https://www.data-mining.co.nz/docker-images/>`__

Interfaces are available for:

- image classification
- image segmentation
- object detection/instance segmentation
- text classification
- text generation

